==> cdbackup_0.6.2.orig.tar.gz: cdbackup-0.6.2/cdrom.h <==
/* cdrom.h
Copyright (c) 2000-2002 Craig Condit, Stefan Hlswitt.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met: 

1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer. 
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution. 

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
*/

#ifndef _CDBACKUP_CDROM_H
#define _CDBACKUP_CDROM_H

extern struct toc_entry *toc;
extern long long cd_used, cd_avail;

int open_cdr(char *device);
void close_cdr(int cd_fd);
int full_read(int fd, void *buf, int count);
int read_toc(int cd_fd, int trackinfos);
void free_toc();
void print_space();

#endif

==> cdbackup_0.6.3.orig.tar.gz: cdbackup-0.6.3/cdrom.h <==
/* cdrom.h
Copyright (c) 2000-2002 Craig Condit, Stefan Hlswitt.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met: 

1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer. 
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution. 

THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
*/

#ifndef _CDBACKUP_CDROM_H
#define _CDBACKUP_CDROM_H

extern struct toc_entry *toc;
extern long long cd_used, cd_avail;

struct toc_entry {
  u_char track_no;	/* track number */
  char is_data;		/* 1 = data track */
  char is_cdbackup;	/* was it created by CD-Backup? */
  int sec_start;	/* start sector */
  int sec_end;		/* last sector */
  char id_str[33];	/* recorder id string (32 chars) */
  char vol_id[33];	/* volume label (32 characters) */
  char t_stamp[13];	/* time stamp: yyyymmddhhmm */
  char disk_set;	/* disk number */
};

int open_cdr(char *device);
void close_cdr(int cd_fd);
void get_param(int fd, unsigned long *ahead, unsigned long *fahead);
void set_param(int fd, unsigned long ahead, unsigned long fahead);
int full_read(int fd, void *buf, int count);
int read_toc(int cd_fd, int trackinfos);
void free_toc();
void print_space();

#endif
